@@ -15,7 +15,7 @@
  *
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
   
@@ -1589,7 +1589,7 @@ int snd_pcm_direct_set_timer_params(snd_pcm_direct_t *dmix)
 	if (dmix->tread) {
 		filter = (1<<SND_TIMER_EVENT_TICK) |
 			 dmix->timer_events;
-		snd_timer_params_set_filter(&params, filter);
+		INTERNAL(snd_timer_params_set_filter)(&params, filter);
 	}
 	ret = snd_timer_params(dmix->timer, &params);
 	if (ret < 0) {
