@@ -77,6 +77,7 @@
 #define i386_dmix_supported_format \
 	((1ULL << SND_PCM_FORMAT_S16_LE) |\
 	 (1ULL << SND_PCM_FORMAT_S32_LE) |\
+	 (1ULL << SND_PCM_FORMAT_S24_LE) |\
 	 (1ULL << SND_PCM_FORMAT_S24_3LE))
 
 #define dmix_supported_format \
@@ -86,6 +87,11 @@ static void mix_select_callbacks(snd_pcm_direct_t *dmix)
 {
 	static int smp = 0, mmx = 0, cmov = 0;
 
+	if (!dmix->direct_memory_access) {
+		generic_mix_select_callbacks(dmix);
+		return;
+	}
+
 	if (!((1ULL<< dmix->shmptr->s.format) & i386_dmix_supported_format)) {
 		generic_mix_select_callbacks(dmix);
 		return;
