@@ -23,7 +23,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -175,6 +175,7 @@ int setparams(snd_pcm_t *phandle, snd_pcm_t *chandle, int *bufsize)
 	snd_pcm_sw_params_t *p_swparams, *c_swparams;
 	snd_pcm_uframes_t p_size, c_size, p_psize, c_psize;
 	unsigned int p_time, c_time;
+	unsigned int val;
 
 	snd_pcm_hw_params_alloca(&p_params);
 	snd_pcm_hw_params_alloca(&c_params);
@@ -226,12 +227,23 @@ int setparams(snd_pcm_t *phandle, snd_pcm_t *chandle, int *bufsize)
 		goto __again;
 
 	snd_pcm_hw_params_get_buffer_size(p_params, &p_size);
-	if (p_psize * 2 < p_size)
+	if (p_psize * 2 < p_size) {
+                snd_pcm_hw_params_get_periods_min(p_params, &val, NULL);
+                if (val > 2) {
+			printf("playback device does not support 2 periods per buffer\n");
+			exit(0);
+		}
 		goto __again;
+	}
 	snd_pcm_hw_params_get_buffer_size(c_params, &c_size);
-	if (c_psize * 2 < c_size)
+	if (c_psize * 2 < c_size) {
+                snd_pcm_hw_params_get_periods_min(c_params, &val, NULL);
+		if (val > 2 ) {
+			printf("capture device does not support 2 periods per buffer\n");
+			exit(0);
+		}
 		goto __again;
-
+	}
 	if ((err = setparams_set(phandle, p_params, p_swparams, "playback")) < 0) {
 		printf("Unable to set sw parameters for playback stream: %s\n", snd_strerror(err));
 		exit(0);
@@ -321,7 +333,7 @@ long timediff(snd_timestamp_t t1, snd_timestamp_t t2)
 	l = (signed long) t1.tv_usec - (signed long) t2.tv_usec;
 	if (l < 0) {
 		t1.tv_sec--;
-		l = -l;
+		l = 1000000 + l;
 		l %= 1000000;
 	}
 	return (t1.tv_sec * 1000000) + l;
@@ -490,7 +502,7 @@ int main(int argc, char *argv[])
 	morehelp = 0;
 	while (1) {
 		int c;
-		if ((c = getopt_long(argc, argv, "hP:C:m:M:F:f:c:r:s:bpen", long_option, NULL)) < 0)
+		if ((c = getopt_long(argc, argv, "hP:C:m:M:F:f:c:r:B:E:s:bpen", long_option, NULL)) < 0)
 			break;
 		switch (c) {
 		case 'h':
